@@ -25,18 +25,18 @@ sub as_html {
     my ($self, %opts) = @_;
     my $ret = "";
 
-    my $children = $self->children;
-    my $texts = [];
+    my $children = $_[0]->{children};
+    my @texts;
     for my $child (@$children) {
         if (ref($child)) {
-            $ret .= $self->as_html_paragraph(join("\n", @$texts), %opts) if join '', @$texts;
-            $texts = [];
+            $ret .= $self->as_html_paragraph(join("\n", @texts), %opts) if join '', @texts;
+            @texts = ();
             $ret .= $child->as_html(%opts);
         } else {
-            push @$texts, $child;
+            push @texts, $child;
         }
     }
-    $ret .= $self->as_html_paragraph(join("\n", @$texts), %opts) if join '', @$texts;
+    $ret .= $self->as_html_paragraph(join("\n", @texts), %opts) if join '', @texts;
 
     $ret;
 }
